@@ -13,6 +13,11 @@ from fastjsonschema import JsonSchemaValueException, compile
 from fastjsonschema.draft07 import CodeGeneratorDraft07
 
 
+def pytest_configure(config):
+    config.addinivalue_line("markers", "none")
+    config.addinivalue_line("markers", "benchmark")
+
+
 @pytest.fixture
 def asserter():
     def f(definition, value, expected, formats={}):
@@ -28,7 +33,8 @@ def asserter():
         if isinstance(expected, JsonSchemaValueException):
             with pytest.raises(JsonSchemaValueException) as exc:
                 validator(value)
-            assert exc.value.message == expected.message
+            if expected.message is not any:
+                assert exc.value.message == expected.message
             assert exc.value.value == (value if expected.value == '{data}' else expected.value)
             assert exc.value.name == expected.name
             assert exc.value.definition == (definition if expected.definition == '{definition}' else expected.definition)
